﻿// 在ASP.NET MVC中实现基于URL的权限控制 示例代码
// http://snowdream.cnblogs.com/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;


namespace Snowdream.Demo.UrlAuthorize
{
    /// <summary>
    /// 账号信息辅助类
    /// </summary>
    public static class AccountHelper
    {
        /// <summary>
        /// 获取权限项
        /// </summary>
        /// <returns>权限项列表</returns>
        public static List<PermissionItem> GetPermissionItems()
        {
            // 如果缓存中已经存在权限列表信息，则直接从缓存中读取。
            if (HttpContext.Current.Cache["PermissionItems"] == null)
            {
                // 如果缓存中没有权限列表信息，则从数据库获取并写入缓存
                UrlAuthorizeEntities db = new UrlAuthorizeEntities();
                var items = db.PermissionItem.Where(c => c.PermissionID > 0).ToList();
                HttpContext.Current.Cache["PermissionItems"] = items;
            }

            // 这个缓存中保存了所有需要进行权限控制的页面所对应的权限ID
            return (List<PermissionItem>)HttpContext.Current.Cache["PermissionItems"];
        }

        /// <summary>
        /// 获取用户权限
        /// </summary>
        /// <param name="userID">用户ID</param>
        /// <returns>用户权限数组</returns>
        public static Int32[] GetUserPermission(int userID)
        {
            // 如果缓存中已经存在权限列表信息，则直接从缓存中读取。
            if (HttpContext.Current.Session["Permission"] == null)
            {
                // 从数据库获取用户权限并将权限ID放到int数组并存入Session
                UrlAuthorizeEntities db = new UrlAuthorizeEntities();
                var permissions = db.PermissionList.Where(c => c.UserID == userID).Select(c=>c.PermissionID).ToArray();
                HttpContext.Current.Session["Permission"] = permissions;
            }
            return (Int32[])HttpContext.Current.Session["Permission"];
        }
    }
}
