﻿// 在ASP.NET MVC中实现基于URL的权限控制 示例代码
// http://snowdream.cnblogs.com/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Web.Mvc;

namespace Snowdream.Demo.UrlAuthorize
{
    /// <summary>
    /// URL授权类
    /// </summary>
    public class UrlAuthorizeAttribute : AuthorizeAttribute
    {
        /// <summary>
        /// 重写OnAuthorization
        /// </summary>
        /// <param name="filterContext"></param>
        public override void OnAuthorization(AuthorizationContext filterContext)
        {
            // 获取权限项列表
            List<PermissionItem> pItems = AccountHelper.GetPermissionItems();

            // 获取当前访问页面对应的权限ID。如果item为空则表示当前页面没有权限控制信息，不需要进行权限控制
            var item = pItems.FirstOrDefault(c => c.Route == filterContext.HttpContext.Request.Path);

            if (item != null)
            {
                if (Array.IndexOf<Int32>(AccountHelper.GetUserPermission(int.Parse(filterContext.HttpContext.Session["UserID"].ToString())), item.PermissionID) == -1)
                {
                    // 提示权限不够，也可以跳转到其他页面
                    filterContext.HttpContext.Response.Write("没有权限访问该页面");
                    filterContext.HttpContext.Response.End();
                }
            }
            else
            {
                // 如果权限项列表中不存在当前页面对应的权限ID则所有用户都不允许访问，直接提示无权访问。
                filterContext.HttpContext.Response.Write("没有权限访问该页面");
                filterContext.HttpContext.Response.End();
            }
        }
    }
}
